@@ -4,10 +4,10 @@
 import os, re
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
+from DebugLog import DebugLog
 
 class QonsoExtractor:
    def __init__(self):
-      self.debug = os.environ.has_key('DEBUG')
       self.urlconso = ""
       self.urlbeforeAuth = ""
       self.urlAuth = ""
@@ -22,7 +22,8 @@ class QonsoExtractor:
       self.authentication = ''
       self.context = ''
       self.status = ''
-      self.SetStatus('INFO', 'Connection au site...')
+      self.offline = False
+      self.SetStatus('INFO', 'Connexion au site...')
       
    def SetView(self, view):
       self.view = view
@@ -32,16 +33,12 @@ class QonsoExtractor:
    
    def SetPassword(self, password):
       self.password = password
-
-   def Debug(self, msg):
-      if self.debug:
-         print msg
-      # f = open('/home/user/debug.txt', 'a')
-      # f.write(msg+"\n")
-      # f.close()
       
+   def SetOffline(self, offline):
+      self.offline = offline
+
    def SetStatus(self, status, context):
-      self.Debug(status+" : "+context)
+      DebugLog(status+" : "+context)
       self.context = context
       self.status = status
       if self.view:
@@ -57,12 +54,10 @@ class QonsoExtractor:
    # 1. charger la page de connection pour récupérer un identifiant
    # 2. ouvrir une requête d'identification avec cet identifiant et le numéro de tél et le code
    def InitAuthenticate(self):
+      DebugLog('Extractor::InitAuthenticate')
       if not self.login or not self.password:
          return
       self.authentication = 'Init'
-
-      self.Debug(self.login)
-      self.Debug(self.password)
       
       self.manager = QNetworkAccessManager()
       QtCore.QObject.connect(self.manager, QtCore.SIGNAL("finished(QNetworkReply *)"), self.readResponse )
@@ -77,7 +72,7 @@ class QonsoExtractor:
    def readResponse(self, reply):
       error = reply.error()
       
-      self.Debug(self.authentication)
+      DebugLog(self.authentication)
       # test d'erreur, en général, pas de connection internet
       if error != QNetworkReply.NoError:
          self.SetStatus('ERROR', "Erreur, v&eacute;rifiez votre connection Internet")
@@ -92,10 +87,19 @@ class QonsoExtractor:
    def DoReadResponse(self, reply):
       pass
 
-   def ExtractDatas(self, datas):
+   def DoExtractDatas(self, datas):
       pass
 
+   def UpdateConso(self):
+      DebugLog( "QonsoExtractor::UpdateConso -> set request="+self.urlconso)
+      self.authentication = 'Done'
+      request = QNetworkRequest()
+      request.setUrl( QtCore.QUrl(self.urlconso) ) 
+      self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
+      self.manager.get(request)
+      
    def PrepareRequest(self):
+      DebugLog( "QonsoExtractor::PrepareRequest")
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl(self.urlAuth) ) 
       request.setHeader(QNetworkRequest.ContentTypeHeader, "application/x-www-form-urlencoded")
@@ -106,6 +110,7 @@ class QonsoExtractor:
       return request
 
    def PostRequest(self, params, request=None):
+      DebugLog( "QonsoExtractor::PostRequest")
       postData = QtCore.QByteArray()
       postData.append(params.toString()[1:])
 
@@ -114,3 +119,20 @@ class QonsoExtractor:
 
       request.setRawHeader("Content-Length", "%s" % postData.length() )
       self.manager.post(request, postData)
+
+   def ExtractDatas(self, datas):
+      DebugLog("QonsoExtractor::ExtractDatas")
+      
+      self.SetStatus('INFO', 'Extraction des donn&eacute;es...')
+      self.DoExtractDatas( str(datas) )
+      self.datasExtracted = True
+      
+      DebugLog('----------------------------------------------\nQonsoExtractor::ExtractDatas done')
+      
+      if self.view:
+         DebugLog("QonsoExtractor:: update view")
+         self.view.update()
+
+      if self.model.NotFilled() and self.status!='ERROR' and not self.offline:
+         DebugLog("QonsoExtractor:: Model not filled! UpdateConso")
+         self.UpdateConso()
