@@ -5,9 +5,12 @@ import re
 from QonsoExtractor import QonsoExtractor
 from PyQt4 import QtWebKit, QtCore
 from PyQt4.QtNetwork import QNetworkRequest
+from DebugLog import DebugLog
 
 class QonsoExtractorBouygues(QonsoExtractor):
    def __init__(self):
+      DebugLog("QonsoExtractorBouygues::init")
+   
       QonsoExtractor.__init__(self)
       
       self.urlconso = "http://www.espaceclient.bouyguestelecom.fr/ECF/jsf/client/conso-factures/details-conso/viewDetailsConso.jsf"
@@ -16,6 +19,8 @@ class QonsoExtractorBouygues(QonsoExtractor):
       self.hostname = "www.espaceclient.bouyguestelecom.fr"
 
    def Authenticate(self, idCorrelation):
+      DebugLog("QonsoExtractorBouygues::Authenticate")
+      
       self.SetStatus('INFO', 'Authentification...')
 
       request = self.PrepareRequest()
@@ -35,11 +40,15 @@ class QonsoExtractorBouygues(QonsoExtractor):
       self.PostRequest(params, request)
       
    def DoReadResponse(self, reply):
+      DebugLog("QonsoExtractorBouygues::DoReadResponse")
+      
       request = QNetworkRequest()
       page = QtWebKit.QWebPage()
       frame = page.currentFrame()
 
       # Phase d'initialisation, on va extraire 'idCorrelation', et on lance l'authentification avec
+      DebugLog("authentication=="+self.authentication)
+      
       if self.authentication=='Init':
          html = reply.readAll()
          frame.setHtml(str(html))
@@ -57,55 +66,60 @@ class QonsoExtractorBouygues(QonsoExtractor):
 
       # Gestion des redirections, il peut y en avoir plusieurs à la suite
       elif self.authentication == 'Redirecting':
+         html = str(reply.readAll())
          possibleRedirectUrl = reply.attribute(QNetworkRequest.RedirectionTargetAttribute)
          redirectUrl = str(possibleRedirectUrl.toUrl().toString())
-         self.Debug(redirectUrl+str(redirectUrl.find("submitLoginError")))
+
+         DebugLog(redirectUrl+str(redirectUrl.find("submitLoginError")))
          
          if redirectUrl and redirectUrl.find("submitLoginError")>0:
             self.SetStatus('ERROR', "Erreur avec vos identifiants")
-            redirectUrl = redirectUrl[ redirectUrl.rfind("http"): ]
-            request.setUrl( QtCore.QUrl(redirectUrl) ) 
+            self.CheckForErrors(html)
+            return
             
          else:
-            self.Debug("No more redirection")
+            DebugLog("No more redirection")
             # pas de redirection, on vérifie s'il n'y a pas d'erreur dans la page
-            html = reply.readAll()
-            frame.setHtml(str(html))
-            errors = frame.findAllElements('div[class=erreur]')
-            if errors:
-               self.Debug("found erreur")
-               for error in errors:
-                  if error.attribute('id'):  # pas cette erreur (div avec id=errorCookie)
-                     continue
-                  self.SetStatus('ERROR', error.toInnerXml())
-                  return
-            else:
-               self.Debug( "Pas d'erreur : "+self.status)
+            html = str(reply.readAll())
+            
+            if not self.CheckForErrors(html):
                # pas d'erreur, c'est Lesieur, on peut charger la page des consommations
-               if self.status == 'ERROR':
-                  return
-               self.authentication = 'Done'
-               self.Debug( "set request="+self.urlconso)
-               request.setUrl( QtCore.QUrl(self.urlconso) ) 
-               self.SetStatus('INFO', 'R&eacute;cup&eacute;ration des donn&eacute;es...')
+               self.UpdateConso()
+               return
             
          self.manager.get(request)
+      
+   def CheckForErrors(self, datas):
+      r = re.compile('<div class="erreur">(.+?)</div>', re.DOTALL)
+      res = r.search(datas)
+               
+      if res:
+         DebugLog("Erreur trouvée : "+str(res.groups()) )
+         error = re.sub( "<.*?>", "", res.group(1)).strip()
          
-   def ExtractDatas(self, datas):
-      self.Debug("ExtractDatas")
-      self.SetStatus('INFO', 'Extraction des donn&eacute;es...')
+         if error:
+            self.SetStatus('ERROR', error)
+            return True
+         else:
+            DebugLog("Pas d'erreur en fait...")
+            return False
+      return False
+      
+   def DoExtractDatas(self, datas):
+      DebugLog("QonsoExtractorBouygues::DoExtractDatas")
 
-      strElem = str(datas)
+      if self.CheckForErrors(datas):
+         return
       
       # Date de la dernière communication
       date = ""
-      res = re.search('DetailConsoDateConso">(\d{1,2}/\d{1,2}/\d{2,4})<', strElem)
+      res = re.search('DetailConsoDateConso">(\d{1,2}/\d{1,2}/\d{2,4})<', datas)
       if res:
          date = res.group(1)
 
       # Heure de la dernière communication
       time = ""
-      res = re.search('DetailConsoHeureConso">(\d{1,2}h\d{1,2})<', strElem)
+      res = re.search('DetailConsoHeureConso">(\d{1,2}h\d{1,2})<', datas)
       if res:
          time = res.group(1)
 
@@ -113,24 +127,24 @@ class QonsoExtractorBouygues(QonsoExtractor):
          self.model.lastTime = "Ma consommation au "+date + " &agrave; " + time
 
       # Date de la prochaine facture
-      res = re.search('dateEmissionFacture">(\d{1,2}/\d{1,2}/\d{2,4})<', strElem)
+      res = re.search('dateEmissionFacture">(\d{1,2}/\d{1,2}/\d{2,4})<', datas)
       if res:
          date = res.group(1)
          self.model.facture = "Prochaine facture : "+date+" au soir"
 
       # Conso Voix
-      self.Debug("____________________________________________\nConso voix")
-      self.Debug("-----------------------------------------------\n")
-      res = re.search("(?:Vous n'avez pas encore profité de)? votre [Ff]orfait (.+?) de %smin" %(self.hmReS), strElem)
+      DebugLog("_______________________________________________\nConso voix")
+      DebugLog("-----------------------------------------------\n")
+      res = re.search("(?:Vous n'avez pas encore profité de)? votre [Ff]orfait (.+?) de %smin" %(self.hmReS), datas)
       if res:
-         self.Debug(res.groups())
+         DebugLog(res.groups())
          self.model.SetForfait( res.group(1) )
          self.model.SetConsoVoixMax( res.group(2) )
          self.model.SetConsoVoix( "0" )
       
-      res = re.search("votre [Ff]orfait (.+) de %smin.+vous avez consomm.+?%s" %(self.hmReS, self.hmReS), strElem)
+      res = re.search("votre [Ff]orfait (.+) de %smin.+vous avez consomm.+?%s" %(self.hmReS, self.hmReS), datas)
       if res:
-         self.Debug(res.groups())
+         DebugLog(res.groups())
          self.model.SetForfait( res.group(1) )
          self.model.SetConsoVoixMax( res.group(2) )
          self.model.SetConsoVoix( res.group(3) )
@@ -142,77 +156,74 @@ class QonsoExtractorBouygues(QonsoExtractor):
 
       # Conso Voix Supplémentaire
       if self.model.forfait.find("Evasio")>-1:
-         self.Debug("____________________________________________\nConso voix Supplémentaire")
-         self.Debug("-----------------------------------------------\n")
-         res = re.search("Sur votre enveloppe.+vous avez consomm.+%s"%self.hmReS, strElem, re.IGNORECASE)
+         DebugLog("_______________________________________________\nConso voix Supplémentaire")
+         DebugLog("-----------------------------------------------\n")
+         res = re.search("Sur votre enveloppe.+vous avez consomm.+%s"%self.hmReS, datas)
          if res:
-            self.Debug(res.groups())
+            DebugLog(res.groups())
             self.model.SetConsoVoixSupp( res.group(1) )
             self.model.SetConsoVoixSuppMax( self.model.GetConsoVoixMax('str') )
 
       # SMS
-      self.Debug("____________________________________________\nConso SMS")
-      self.Debug("-----------------------------------------------\n")
-      res = re.search("pas encore profité de votre [Ff]orfait de (\d+) SMS", strElem)
+      DebugLog("_______________________________________________\nConso SMS")
+      DebugLog("-----------------------------------------------\n")
+      res = re.search("pas encore profité de votre [Ff]orfait de (\d+) SMS", datas)
       if res:
-         self.Debug(res.groups())
+         DebugLog(res.groups())
          self.model.SetConsoSMS( '0' )
          self.model.SetConsoSMSMax( res.group(1) )
       else:
-         res = re.search("Sur votre [Ff]orfait de (\d+) SMS.+vous avez consomm.+?(\d+) SMS", strElem)
+         res = re.search("Sur votre [Ff]orfait de (\d+) SMS.+vous avez consomm.+?(\d+) SMS", datas)
          if res:
-            self.Debug(res.groups())
+            DebugLog(res.groups())
             self.model.SetConsoSMS( res.group(2) )
             self.model.SetConsoSMSMax( res.group(1) )
 
       # Bonus SMS
-      self.Debug("____________________________________________\nBonus SMS")
-      self.Debug("-----------------------------------------------\n")
-      res = re.search("avez consommé (.+?) de votre bonus de (\d+) SMS", strElem)
+      DebugLog("_______________________________________________\nBonus SMS")
+      DebugLog("-----------------------------------------------\n")
+      res = re.search("avez consommé (.+?) de votre bonus de (\d+) SMS", datas)
       if res:
-         self.Debug(res.groups())
+         DebugLog(res.groups())
          if res.group(1)=='la totalité':
             self.model.SetConsoSMSSupp( res.group(2) )
          else:
             self.model.SetConsoSMSSupp( res.group(1) )
          self.model.SetConsoSMSSuppMax( res.group(2) )
       else:
-         res = re.search("pas encore.+?votre bonus de (\d+) SMS", strElem)
+         res = re.search("pas encore.+?votre bonus de (\d+) SMS", datas)
          if res:
-            self.Debug(res.groups())
+            DebugLog(res.groups())
             self.model.SetConsoSMSSupp( '0' )
             self.model.SetConsoSMSSuppMax( res.group(1) )
          else:
-            res = re.search("votre bonus de (\d+) SMS.+?vous avez consommé.+?(\d+) SMS", strElem)
+            res = re.search("votre bonus de (\d+) SMS.+?vous avez consommé.+?(\d+) SMS", datas)
             if res:
-               self.Debug(res.groups())
+               DebugLog(res.groups())
                self.model.SetConsoSMSSupp( res.group(2) )
                self.model.SetConsoSMSSuppMax( res.group(1) )
          
       # Report de minutes
-      self.Debug("____________________________________________\nReport de minutes")
-      self.Debug("-----------------------------------------------\n")
-      res = re.search("report de minutes.*Pas de report", strElem, re.IGNORECASE)
+      DebugLog("_______________________________________________\nReport de minutes")
+      DebugLog("-----------------------------------------------\n")
+      res = re.search("[Rr]eport de minutes.*Pas de report", datas)
       if not res:
-         res = re.search("report de minutes.*?<span>.*?%s.*?</span>"%self.hmReS, strElem, re.IGNORECASE)
+         res = re.search("[Rr]eport de minutes.*?<span>.*?%s.*?</span>"%self.hmReS, datas)
          if res:
             self.model.SetReport( res.group(1) )
-            self.Debug("report = "+res.group(1))
+            DebugLog("report = "+res.group(1))
          else:
-            res = re.search("report de minutes de\s*%s" % self.hmReS, strElem, re.IGNORECASE)
+            res = re.search("[Rr]eport de minutes de\s*%s" % self.hmReS, datas)
             if res:
                self.model.SetReport( res.group(1) )
-               self.Debug("report = "+res.group(1))
+               DebugLog("report = "+res.group(1))
 
       # Hors forfait
-      self.Debug("____________________________________________\nHors forfait")
-      self.Debug("-----------------------------------------------\n")
-      reHForfait = re.compile(u"montant hors forfait.*?(\d+[\.,]?\d*)\s", re.IGNORECASE|re.DOTALL)
-      res = reHForfait.search(strElem)
+      DebugLog("_______________________________________________\nHors forfait")
+      DebugLog("-----------------------------------------------\n")
+      reHForfait = re.compile(u"[Mm]ontant [Hh]ors [Ff]orfait.*?(\d+[\.,]?\d*)\s", re.DOTALL)
+      res = reHForfait.search(datas)
       if res:
          self.model.SetConsoHorsForfait( res.group(1) )
-         self.Debug("hforfait = "+res.group(1))
-      
-      self.datasExtracted = True
-      if self.view:
-         self.view.update()
+         DebugLog("hforfait = "+res.group(1))
+      
\ No newline at end of file
