@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import re
+from DebugLog import DebugLog
 
 class QonsoModel:
    def __init__(self):
@@ -23,6 +24,14 @@ class QonsoModel:
       self.regHM = re.compile("(\d+\s*[Hh])?\s*(\d+)", re.DOTALL)
 #      self.regHM = "(\d+)*?\s*[Hh]?\s*(\d+)"
       
+   def NotFilled(self):
+      if not self.GetLastTime():
+         DebugLog("QonsoModel::NotFilled True")
+         return True
+      else:
+         DebugLog("QonsoModel::NotFilled True")
+         return False
+      
    def GetLastTime(self):
       return self.lastTime
 
