@@ -7,15 +7,27 @@ import QonsoFactory
 from QonsoModel import QonsoModel
 from DlgConfig import DlgConfig
 from WProgress import WProgress
+from DebugLog import DebugLog
 
 class QonsoView(QtGui.QMainWindow):
    def __init__(self, argv, parent=None):
       QtGui.QMainWindow.__init__(self, parent)
       
+      DebugLog("QonsoView::Init")
       self.offline = os.environ.has_key('OFFLINE')
       self.setMaximumSize(QtCore.QSize(800, 480))
       self.setWindowTitle('Qonso')
-      
+
+      self.vbox = None
+      self.boxes = dict(
+                  voix=None,
+                  voixSupp = None,
+                  sms = None,
+                  smsSupp = None,
+                  data = None,
+                  hforfait = None,
+                  facture = None)
+
       try:
          self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
       except AttributeError:
@@ -25,33 +37,39 @@ class QonsoView(QtGui.QMainWindow):
       self.labels = dict()
       self.config = DlgConfig()
       self.model = QonsoModel()
-      
+      self.extractor = None
       self.credentialsOk = False
       
       if not self.config.GetLogin() or not self.config.GetPassword() or not self.config.GetOperator():
          self.config.AskForCredentials()
       
-      self.CreateExtractor( self.config.GetOperator() )
-      
       self.layoutsOK = False
       self.centralWidget = QtGui.QWidget()
 
       self.vbox = QtGui.QVBoxLayout()
       self.centralWidget.setLayout(self.vbox)
       self.setCentralWidget( self.centralWidget )
-      self.firstDisplay = None
+      self.firstDisplay = True
       
       self.credentialsOk = True
       self.CreateAppLayouts()
 
+   def DataInit(self):
+      DebugLog("QonsoView::DataInit")
       if self.offline:
          self.CreateExtractor(sys.argv[1])
          f = open( sys.argv[2], "r")
+         self.extractor.SetOffline(True)
          self.extractor.ExtractDatas( f.read() )
          f.close()
          self.CreateConsoLayouts()
+         self.extractor.authentication = 'Done'
+      else:
+         self.CreateExtractor( self.config.GetOperator() )
+         self.extractor.InitAuthenticate()
 
    def CreateExtractor(self, op):
+      DebugLog("QonsoView::CreateExtractor")
       self.extractor = QonsoFactory.CreateExtractor(op)
       self.extractor.SetView(self)
       self.extractor.SetLogin(self.config.GetLogin())
@@ -60,11 +78,29 @@ class QonsoView(QtGui.QMainWindow):
       
    def Settings(self):
       self.config.AskForCredentials()
-      self.credentialsOk = True
-      self.CreateExtractor(self.config.GetOperator())
-      self.extractor.InitAuthenticate()
+      if self.config.updated:
+         for box in self.boxes:
+            if self.boxes[box]:
+            
+               if box != 'lasttime':
+                  l, w = self.labels[box]
+                  if l:
+                     print "removing "+box
+                     self.boxes[box].removeWidget(l)
+                  if w:
+                     self.boxes[box].removeWidget(w)
+                  self.labels.pop(box)
+            
+                  self.vbox.removeItem(self.boxes[box])
+                  self.boxes[box] = None
+
+         self.update()
+         self.credentialsOk = True
+         self.layoutsOK = False
+         self.extractor = None
       
    def CreateAppLayouts(self):      
+      DebugLog("QonsoView::CreateAppLayouts")
       exit = QtGui.QAction(QtGui.QIcon('icons/exit.png'), u'Paramètres', self)
       exit.setShortcut('Ctrl+O')
       exit.setStatusTip('Options')
@@ -79,44 +115,48 @@ class QonsoView(QtGui.QMainWindow):
       
       self.vbox.setSpacing(0)
       self.vbox.setMargin(0)
-      self.layoutsOK = True
-   
    
    def CreateConsoLayouts(self):
+      DebugLog("QonsoView::CreateConsoLayouts")
+      
       iconPath = '/opt/qonso/icons'
       if not os.path.exists(iconPath):
          iconPath = 'icons'
       
-      voixBox = self.CreateLayout('voix', os.path.join(iconPath, 'voix.png'), True)
-      self.vbox.addLayout(voixBox)
+      self.boxes['voix'] = self.CreateLayout('voix', os.path.join(iconPath, 'voix.png'), True)
+      self.vbox.addLayout(self.boxes['voix'])
       
       if self.model.GetConsoVoixSupp('str'):
-         voixSupBox = self.CreateLayout('voixSupp', os.path.join(iconPath, 'voixsupp.png'), True)
-         self.vbox.addLayout(voixSupBox)
+         self.boxes['voixSupp'] = self.CreateLayout('voixSupp', os.path.join(iconPath, 'voixsupp.png'), True)
+         self.vbox.addLayout(self.boxes['voixSupp'])
       
       if self.model.GetConsoSMSMax() != '0':
-         smsBox = self.CreateLayout('sms', os.path.join(iconPath, 'sms.png') )
-         self.vbox.addLayout(smsBox)
+         self.boxes['sms'] = self.CreateLayout('sms', os.path.join(iconPath, 'sms.png') )
+         self.vbox.addLayout(self.boxes['sms'])
       
       if self.model.GetConsoSMSSupp():
-         smsSupBox = self.CreateLayout('smsSupp', os.path.join(iconPath, 'smssupp.png') )
-         self.vbox.addLayout(smsSupBox)
+         self.boxes['smsSupp'] = self.CreateLayout('smsSupp', os.path.join(iconPath, 'smssupp.png') )
+         self.vbox.addLayout(self.boxes['smsSupp'])
          
-      dataBox = self.CreateLayout('data', os.path.join(iconPath, 'data.png'), True)
-      self.vbox.addLayout(dataBox)
+      self.boxes['data'] = self.CreateLayout('data', os.path.join(iconPath, 'data.png'), True)
+      self.vbox.addLayout(self.boxes['data'])
 
-      hforfaitBox = self.CreateLayout('hforfait', os.path.join(iconPath, 'hforfait.png'), False)
-      self.vbox.addLayout(hforfaitBox)
+      self.boxes['hforfait'] = self.CreateLayout('hforfait', os.path.join(iconPath, 'hforfait.png'), False)
+      self.vbox.addLayout(self.boxes['hforfait'])
 
-      factureBox = self.CreateLayout('facture', None)
-      self.vbox.addLayout(factureBox)
+      self.boxes['facture'] = self.CreateLayout('facture', None)
+      self.vbox.addLayout(self.boxes['facture'])
 
+      self.layoutsOK = True
       self.UpdateConsoText()
-      
 
    def CreateLayout(self, name, icon, progress=False):
+      DebugLog("QonsoView::CreateLayout(%s, %s, %d)" % (name, str(icon), progress) )
+      
       box = QtGui.QHBoxLayout()
       box.setSpacing(0)
+      box.setMargin(0)
+      
       if icon:
          pixicon = QtGui.QPixmap(icon).scaled(64,64)
          label = QtGui.QLabel()
@@ -155,6 +195,9 @@ class QonsoView(QtGui.QMainWindow):
       return box
 
    def UpdateConsoText(self):
+      if not self.extractor:
+         return 
+      
       status, context = self.extractor.GetStatus()
       
       if status=='ERROR':
@@ -176,7 +219,7 @@ class QonsoView(QtGui.QMainWindow):
          self.labels['voixSupp'][1].setRange(0, self.model.GetConsoVoixMax('int'))
          self.labels['voixSupp'][1].setValue( self.model.GetConsoVoixSuppMax('int') )
 
-      if self.model.GetConsoSMSMax() != '0':
+      if self.labels.has_key('sms'): # and self.model.GetConsoSMSMax() != '0':
          self.SetText(self.labels['sms'][0], "#EB5F18", 20, self.model.GetConsoSMS() +"/" + self.model.GetConsoSMSMax())
 
       if self.labels.has_key('smsSupp'):
@@ -200,11 +243,10 @@ class QonsoView(QtGui.QMainWindow):
    
    def paintEvent(self, event):
       if self.firstDisplay:
-         if self.credentialsOk and not self.extractor.authentication:
-            if not self.offline:
-               self.extractor.InitAuthenticate()
-         elif self.layoutsOK:
-            if self.extractor.datasExtracted:
+         if self.credentialsOk and (not self.extractor or not self.extractor.authentication):
+            self.DataInit()
+         elif not self.layoutsOK:
+            if self.extractor and self.extractor.datasExtracted:
                self.CreateConsoLayouts()
                self.extractor.datasExtracted = False 
       self.firstDisplay = True
@@ -213,4 +255,3 @@ class QonsoView(QtGui.QMainWindow):
    def closeEvent(self, event):
       self.config.WriteConfig()
       event.accept()
-	  
